@@ -10,12 +10,12 @@ class WordFilter(BaseFilter):
         ('--word', {'action':'store', 'nargs':'*', 'help':'only output lines matching any of WORD'}),
     ]
 
-    def __init__(self, commandLineArgs):
-        BaseFilter.__init__(self, commandLineArgs)
+    def __init__(self, mlogfilter):
+        BaseFilter.__init__(self, mlogfilter)
 
         # extract all arguments passed into 'word'
-        if 'word' in self.commandLineArgs and self.commandLineArgs['word']:
-            self.words = self.commandLineArgs['word'].split()
+        if 'word' in self.mlogfilter.args and self.mlogfilter.args['word']:
+            self.words = self.mlogfilter.args['word'].split()
             self.active = True
         else:
             self.active = False
