@@ -27,9 +27,9 @@ class HistogramPlotType(BasePlotType):
         BasePlotType.__init__(self, args, unknown_args)
 
         # parse arguments further to get --bucketsize argument
-        self.argparser = argparse.ArgumentParser("mplotqueries --type histogram")
-        self.argparser.add_argument('--bucketsize', '-b', action='store', metavar='SIZE', help="histogram bucket size in seconds", default=60)
-        sub_args = vars(self.argparser.parse_args(unknown_args))
+        argparser = argparse.ArgumentParser("mplotqueries --type histogram")
+        argparser.add_argument('--bucketsize', '-b', action='store', metavar='SIZE', help="histogram bucket size in seconds", default=60)
+        sub_args = vars(argparser.parse_args(unknown_args))
 
         self.logscale = args['logscale']
         # get bucket size, either as int (seconds) or as string (see timeunits above)
@@ -88,12 +88,12 @@ class HistogramPlotType(BasePlotType):
             axis.patch.set_visible(False) # hide the 'canvas' 
             axis = twin_axis
 
-        n_bins = (maxx-minx)*24.*60.*60./self.bucketsize
+        n_bins = n_bins = max(1, int((maxx - minx)*24.*60.*60./self.bucketsize))
         if n_bins > 1000:
             # warning for too many buckets
             print "warning: %i buckets, will take a while to render. consider increasing --bucketsize." % n_bins
 
-        n, bins, artists = axis.hist(datasets, bins=n_bins, align='mid', log=self.logscale, histtype="barstacked", color=colors, edgecolor="white", alpha=0.65, picker=True, label=map(str, self.groups.keys()))
+        n, bins, artists = axis.hist(datasets, bins=n_bins, align='mid', log=self.logscale, histtype="barstacked", color=colors, edgecolor="white", alpha=0.7, picker=True, label=map(str, self.groups.keys()))
         
         # scale current y-axis to match min and max values
         axis.set_ylim(np.min(n), np.max(n))
